Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(609)

Unified Diff: components/reading_list/core/reading_list_entry.h

Issue 2763233003: Move ReadingList model to components/reading_list/core (Closed)
Patch Set: feedback Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/reading_list/core/reading_list_entry.h
diff --git a/components/reading_list/ios/reading_list_entry.h b/components/reading_list/core/reading_list_entry.h
similarity index 95%
rename from components/reading_list/ios/reading_list_entry.h
rename to components/reading_list/core/reading_list_entry.h
index f296a220897b8755bfac29a51a5a24dbcd31b8be..042cf05ca6b9bffec351cc85bc59b69e9795c98f 100644
--- a/components/reading_list/ios/reading_list_entry.h
+++ b/components/reading_list/core/reading_list_entry.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_READING_LIST_IOS_READING_LIST_ENTRY_H_
-#define COMPONENTS_READING_LIST_IOS_READING_LIST_ENTRY_H_
+#ifndef COMPONENTS_READING_LIST_CORE_READING_LIST_ENTRY_H_
+#define COMPONENTS_READING_LIST_CORE_READING_LIST_ENTRY_H_
#include <string>
@@ -62,8 +62,14 @@ class ReadingListEntry {
// Entries are created in WAITING state. At some point they will be PROCESSING
// into one of the three state: PROCESSED, the only state a distilled URL
// would be set, WILL_RETRY, similar to wait, but with exponential delays or
- // ERROR where the system will not retry at all.
- enum DistillationState { WAITING, PROCESSING, PROCESSED, WILL_RETRY, ERROR };
+ // DISTILLATION_ERROR where the system will not retry at all.
+ enum DistillationState {
+ WAITING,
+ PROCESSING,
+ PROCESSED,
+ WILL_RETRY,
+ DISTILLATION_ERROR
+ };
static const net::BackoffEntry::Policy kBackoffPolicy;
@@ -206,4 +212,4 @@ class ReadingListEntry {
DISALLOW_COPY_AND_ASSIGN(ReadingListEntry);
};
-#endif // COMPONENTS_READING_LIST_IOS_READING_LIST_ENTRY_H_
+#endif // COMPONENTS_READING_LIST_CORE_READING_LIST_ENTRY_H_
« no previous file with comments | « components/reading_list/core/proto/reading_list.proto ('k') | components/reading_list/core/reading_list_entry.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698